# AlgorithmResultStatus


## Enum

* `PENDING` (value: `'Pending'`)

* `COMPLETE` (value: `'Complete'`)

* `ERROR` (value: `'Error'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


